# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SenderRequestStatus(str, Enum):
    """
    Status of the application for Sender registration. Possible values:  - new – application created  - accepted – accepted  - in progress – in progress  - registration completed – Sender registration completed  - rejected – application for Sender registration rejected 
    """

    """
    allowed enum values
    """
    NEW = 'new'
    ACCEPTED = 'accepted'
    IN_PROGRESS = 'in_progress'
    REGISTERED = 'registered'
    REJECTED = 'rejected'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SenderRequestStatus from a JSON string"""
        return cls(json.loads(json_str))


