# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictInt, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from bsg_api.models.get_messages200_response import GetMessages200Response
from bsg_api.models.sort_way import SortWay

from bsg_api.api_client import ApiClient, RequestSerialized
from bsg_api.api_response import ApiResponse
from bsg_api.rest import RESTResponseType


class MessagesSMSApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_messages(
        self,
        page_offset: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        page_limit: Annotated[Optional[Annotated[int, Field(le=500, strict=True, ge=15)]], Field(description="The number of items in the response")] = None,
        sort: Annotated[Optional[StrictStr], Field(description="Field to sort the results")] = None,
        way: Optional[SortWay] = None,
        filter_id: Optional[Annotated[int, Field(strict=True, ge=1)]] = None,
        filter_campaign_id: Annotated[Optional[StrictInt], Field(description="Filter by campaign Id received when [send message](#operation/sms_send)")] = None,
        filter_reference_id: Annotated[Optional[StrictStr], Field(description="Filter by reference passed when [send message](#operation/sms_send)")] = None,
        filter_from: Annotated[Optional[datetime], Field(description="Filter message from this date. format ― Y-m-d H:i:s")] = None,
        filter_to: Annotated[Optional[datetime], Field(description="Filter message up to this date. format ― Y-m-d H:i:s")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GetMessages200Response:
        """Find messages


        :param page_offset:
        :type page_offset: int
        :param page_limit: The number of items in the response
        :type page_limit: int
        :param sort: Field to sort the results
        :type sort: str
        :param way:
        :type way: SortWay
        :param filter_id:
        :type filter_id: int
        :param filter_campaign_id: Filter by campaign Id received when [send message](#operation/sms_send)
        :type filter_campaign_id: int
        :param filter_reference_id: Filter by reference passed when [send message](#operation/sms_send)
        :type filter_reference_id: str
        :param filter_from: Filter message from this date. format ― Y-m-d H:i:s
        :type filter_from: datetime
        :param filter_to: Filter message up to this date. format ― Y-m-d H:i:s
        :type filter_to: datetime
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_messages_serialize(
            page_offset=page_offset,
            page_limit=page_limit,
            sort=sort,
            way=way,
            filter_id=filter_id,
            filter_campaign_id=filter_campaign_id,
            filter_reference_id=filter_reference_id,
            filter_from=filter_from,
            filter_to=filter_to,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetMessages200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_messages_with_http_info(
        self,
        page_offset: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        page_limit: Annotated[Optional[Annotated[int, Field(le=500, strict=True, ge=15)]], Field(description="The number of items in the response")] = None,
        sort: Annotated[Optional[StrictStr], Field(description="Field to sort the results")] = None,
        way: Optional[SortWay] = None,
        filter_id: Optional[Annotated[int, Field(strict=True, ge=1)]] = None,
        filter_campaign_id: Annotated[Optional[StrictInt], Field(description="Filter by campaign Id received when [send message](#operation/sms_send)")] = None,
        filter_reference_id: Annotated[Optional[StrictStr], Field(description="Filter by reference passed when [send message](#operation/sms_send)")] = None,
        filter_from: Annotated[Optional[datetime], Field(description="Filter message from this date. format ― Y-m-d H:i:s")] = None,
        filter_to: Annotated[Optional[datetime], Field(description="Filter message up to this date. format ― Y-m-d H:i:s")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GetMessages200Response]:
        """Find messages


        :param page_offset:
        :type page_offset: int
        :param page_limit: The number of items in the response
        :type page_limit: int
        :param sort: Field to sort the results
        :type sort: str
        :param way:
        :type way: SortWay
        :param filter_id:
        :type filter_id: int
        :param filter_campaign_id: Filter by campaign Id received when [send message](#operation/sms_send)
        :type filter_campaign_id: int
        :param filter_reference_id: Filter by reference passed when [send message](#operation/sms_send)
        :type filter_reference_id: str
        :param filter_from: Filter message from this date. format ― Y-m-d H:i:s
        :type filter_from: datetime
        :param filter_to: Filter message up to this date. format ― Y-m-d H:i:s
        :type filter_to: datetime
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_messages_serialize(
            page_offset=page_offset,
            page_limit=page_limit,
            sort=sort,
            way=way,
            filter_id=filter_id,
            filter_campaign_id=filter_campaign_id,
            filter_reference_id=filter_reference_id,
            filter_from=filter_from,
            filter_to=filter_to,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetMessages200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_messages_without_preload_content(
        self,
        page_offset: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        page_limit: Annotated[Optional[Annotated[int, Field(le=500, strict=True, ge=15)]], Field(description="The number of items in the response")] = None,
        sort: Annotated[Optional[StrictStr], Field(description="Field to sort the results")] = None,
        way: Optional[SortWay] = None,
        filter_id: Optional[Annotated[int, Field(strict=True, ge=1)]] = None,
        filter_campaign_id: Annotated[Optional[StrictInt], Field(description="Filter by campaign Id received when [send message](#operation/sms_send)")] = None,
        filter_reference_id: Annotated[Optional[StrictStr], Field(description="Filter by reference passed when [send message](#operation/sms_send)")] = None,
        filter_from: Annotated[Optional[datetime], Field(description="Filter message from this date. format ― Y-m-d H:i:s")] = None,
        filter_to: Annotated[Optional[datetime], Field(description="Filter message up to this date. format ― Y-m-d H:i:s")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Find messages


        :param page_offset:
        :type page_offset: int
        :param page_limit: The number of items in the response
        :type page_limit: int
        :param sort: Field to sort the results
        :type sort: str
        :param way:
        :type way: SortWay
        :param filter_id:
        :type filter_id: int
        :param filter_campaign_id: Filter by campaign Id received when [send message](#operation/sms_send)
        :type filter_campaign_id: int
        :param filter_reference_id: Filter by reference passed when [send message](#operation/sms_send)
        :type filter_reference_id: str
        :param filter_from: Filter message from this date. format ― Y-m-d H:i:s
        :type filter_from: datetime
        :param filter_to: Filter message up to this date. format ― Y-m-d H:i:s
        :type filter_to: datetime
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_messages_serialize(
            page_offset=page_offset,
            page_limit=page_limit,
            sort=sort,
            way=way,
            filter_id=filter_id,
            filter_campaign_id=filter_campaign_id,
            filter_reference_id=filter_reference_id,
            filter_from=filter_from,
            filter_to=filter_to,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetMessages200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_messages_serialize(
        self,
        page_offset,
        page_limit,
        sort,
        way,
        filter_id,
        filter_campaign_id,
        filter_reference_id,
        filter_from,
        filter_to,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page_offset is not None:
            
            _query_params.append(('page[offset]', page_offset))
            
        if page_limit is not None:
            
            _query_params.append(('page[limit]', page_limit))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if way is not None:
            
            _query_params.append(('way', way.value))
            
        if filter_id is not None:
            
            _query_params.append(('filter[id]', filter_id))
            
        if filter_campaign_id is not None:
            
            _query_params.append(('filter[campaign_id]', filter_campaign_id))
            
        if filter_reference_id is not None:
            
            _query_params.append(('filter[reference_id]', filter_reference_id))
            
        if filter_from is not None:
            if isinstance(filter_from, datetime):
                _query_params.append(
                    (
                        'filter[from]',
                        filter_from.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('filter[from]', filter_from))
            
        if filter_to is not None:
            if isinstance(filter_to, datetime):
                _query_params.append(
                    (
                        'filter[to]',
                        filter_to.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('filter[to]', filter_to))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ExternalAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/messages',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


