# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from bsg_api.models.phone import Phone
from bsg_api.models.rcs import Rcs
from bsg_api.models.sms import Sms
from bsg_api.models.telegram import Telegram
from bsg_api.models.viber import Viber
from bsg_api.models.voice import Voice
from typing import Optional, Set
from typing_extensions import Self

class MessageUniversal(BaseModel):
    """
    A message that can be of type SMS, WhatsApp, or RCS.
    """ # noqa: E501
    channels: Annotated[List[StrictStr], Field(min_length=1, max_length=2)]
    phone: Phone
    rcs: Optional[Rcs] = None
    viber: Optional[Viber] = None
    sms: Optional[Sms] = None
    voice: Optional[Voice] = None
    telegram: Optional[Telegram] = None
    callback_url: Optional[Any] = Field(default=None, description="Link to get the delivery status of messages. If this parameter is specified in the method, it will take precedence over the value specified in the “Callback URL” field in the Personal Area.")
    tariff_code: Optional[StrictInt] = Field(default=None, description="Tariff code null by default. Your can pass specified one if you have several. For more information please visit the [account prices](https://app.bsg.world/prices/sms)")
    validity: Optional[Annotated[int, Field(le=72, strict=True, ge=1)]] = Field(default=72, description="validity time in hours. The default is 72 hours. Integer from 1 to 72")
    validity_seconds: Optional[Annotated[int, Field(le=86400, strict=True, ge=30)]] = Field(default=None, description="Message validity period in seconds. After this period expires, the message will be in **EXPIRED** status or will be redirected to the SMS channel if it was specified in the request. Incompatible with **validity**")
    respect_curfew: Optional[StrictBool] = Field(default=False, description="Check the curfew if it's set up in user settings.")
    add_to_contact_book: Optional[StrictBool] = Field(default=True, description="Specifies whether to add the specified phone number of the message recipient to the contact book")
    check_stop_list: Optional[StrictBool] = Field(default=True, description="Check the recipient’s phone number for being in the stop list.  Possible values:    - true – if the number is found in the stop list, do not send the message  - false – ignore the stop list")
    dry_run: Optional[StrictBool] = Field(default=False, description="Allows you to check the validity of the request without actual message sending")
    __properties: ClassVar[List[str]] = ["channels", "phone", "rcs", "viber", "sms", "voice", "telegram", "callback_url", "tariff_code", "validity", "validity_seconds", "respect_curfew", "add_to_contact_book", "check_stop_list", "dry_run"]

    @field_validator('channels')
    def channels_validate_enum(cls, value):
        """Validates the enum"""
        for i in value:
            if i not in set(['sms', 'rcs', 'viber', 'voice', 'telegram']):
                raise ValueError("each list item must be one of ('sms', 'rcs', 'viber', 'voice', 'telegram')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MessageUniversal from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of phone
        if self.phone:
            _dict['phone'] = self.phone.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rcs
        if self.rcs:
            _dict['rcs'] = self.rcs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of viber
        if self.viber:
            _dict['viber'] = self.viber.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sms
        if self.sms:
            _dict['sms'] = self.sms.to_dict()
        # override the default output from pydantic by calling `to_dict()` of voice
        if self.voice:
            _dict['voice'] = self.voice.to_dict()
        # override the default output from pydantic by calling `to_dict()` of telegram
        if self.telegram:
            _dict['telegram'] = self.telegram.to_dict()
        # set to None if callback_url (nullable) is None
        # and model_fields_set contains the field
        if self.callback_url is None and "callback_url" in self.model_fields_set:
            _dict['callback_url'] = None

        # set to None if dry_run (nullable) is None
        # and model_fields_set contains the field
        if self.dry_run is None and "dry_run" in self.model_fields_set:
            _dict['dry_run'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MessageUniversal from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "channels": obj.get("channels"),
            "phone": Phone.from_dict(obj["phone"]) if obj.get("phone") is not None else None,
            "rcs": Rcs.from_dict(obj["rcs"]) if obj.get("rcs") is not None else None,
            "viber": Viber.from_dict(obj["viber"]) if obj.get("viber") is not None else None,
            "sms": Sms.from_dict(obj["sms"]) if obj.get("sms") is not None else None,
            "voice": Voice.from_dict(obj["voice"]) if obj.get("voice") is not None else None,
            "telegram": Telegram.from_dict(obj["telegram"]) if obj.get("telegram") is not None else None,
            "callback_url": obj.get("callback_url"),
            "tariff_code": obj.get("tariff_code"),
            "validity": obj.get("validity") if obj.get("validity") is not None else 72,
            "validity_seconds": obj.get("validity_seconds"),
            "respect_curfew": obj.get("respect_curfew") if obj.get("respect_curfew") is not None else False,
            "add_to_contact_book": obj.get("add_to_contact_book") if obj.get("add_to_contact_book") is not None else True,
            "check_stop_list": obj.get("check_stop_list") if obj.get("check_stop_list") is not None else True,
            "dry_run": obj.get("dry_run") if obj.get("dry_run") is not None else False
        })
        return _obj


