# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from bsg_api.models.rcs import Rcs
from bsg_api.models.recipients import Recipients
from bsg_api.models.sms import Sms
from bsg_api.models.telegram import Telegram
from bsg_api.models.viber import Viber
from bsg_api.models.voice import Voice
from typing import Optional, Set
from typing_extensions import Self

class Campaign(BaseModel):
    """
    Campaign
    """ # noqa: E501
    tariff_code: Optional[StrictInt] = Field(default=None, description="Tariff code null by default. Your can pass specified one if you have several. For more information please visit the [account prices](https://app.bsg.world/prices/sms)")
    validity: Optional[Annotated[int, Field(le=72, strict=True, ge=1)]] = Field(default=72, description="validity time in hours. The default is 72 hours. Integer from 1 to 72")
    start_at: Optional[datetime] = Field(default=None, description="Start sending the messages at")
    add_to_contact_book: Optional[StrictBool] = Field(default=True, description="Specifies whether to add the specified phone number of the message recipient to the contact book")
    check_stop_list: Optional[StrictBool] = Field(default=True, description="Check the recipient’s phone number for being in the stop list.  Possible values:    - true – if the number is found in the stop list, do not send the message  - false – ignore the stop list")
    recipients: Recipients
    channels: Annotated[List[StrictStr], Field(min_length=1, max_length=2)]
    rcs: Optional[Rcs] = None
    viber: Optional[Viber] = None
    sms: Optional[Sms] = None
    voice: Optional[Voice] = None
    telegram: Optional[Telegram] = None
    dry_run: Optional[StrictBool] = Field(default=False, description="Allows you to check the validity of the request without actual campaign sending")
    __properties: ClassVar[List[str]] = ["tariff_code", "validity", "start_at", "add_to_contact_book", "check_stop_list", "recipients", "channels", "rcs", "viber", "sms", "voice", "telegram", "dry_run"]

    @field_validator('channels')
    def channels_validate_enum(cls, value):
        """Validates the enum"""
        for i in value:
            if i not in set(['sms', 'rcs', 'viber', 'voice', 'telegram']):
                raise ValueError("each list item must be one of ('sms', 'rcs', 'viber', 'voice', 'telegram')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Campaign from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of recipients
        if self.recipients:
            _dict['recipients'] = self.recipients.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rcs
        if self.rcs:
            _dict['rcs'] = self.rcs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of viber
        if self.viber:
            _dict['viber'] = self.viber.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sms
        if self.sms:
            _dict['sms'] = self.sms.to_dict()
        # override the default output from pydantic by calling `to_dict()` of voice
        if self.voice:
            _dict['voice'] = self.voice.to_dict()
        # override the default output from pydantic by calling `to_dict()` of telegram
        if self.telegram:
            _dict['telegram'] = self.telegram.to_dict()
        # set to None if dry_run (nullable) is None
        # and model_fields_set contains the field
        if self.dry_run is None and "dry_run" in self.model_fields_set:
            _dict['dry_run'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Campaign from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "tariff_code": obj.get("tariff_code"),
            "validity": obj.get("validity") if obj.get("validity") is not None else 72,
            "start_at": obj.get("start_at"),
            "add_to_contact_book": obj.get("add_to_contact_book") if obj.get("add_to_contact_book") is not None else True,
            "check_stop_list": obj.get("check_stop_list") if obj.get("check_stop_list") is not None else True,
            "recipients": Recipients.from_dict(obj["recipients"]) if obj.get("recipients") is not None else None,
            "channels": obj.get("channels"),
            "rcs": Rcs.from_dict(obj["rcs"]) if obj.get("rcs") is not None else None,
            "viber": Viber.from_dict(obj["viber"]) if obj.get("viber") is not None else None,
            "sms": Sms.from_dict(obj["sms"]) if obj.get("sms") is not None else None,
            "voice": Voice.from_dict(obj["voice"]) if obj.get("voice") is not None else None,
            "telegram": Telegram.from_dict(obj["telegram"]) if obj.get("telegram") is not None else None,
            "dry_run": obj.get("dry_run") if obj.get("dry_run") is not None else False
        })
        return _obj


