# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from bsg_api.models.otp_template_status import OtpTemplateStatus
from typing import Optional, Set
from typing_extensions import Self

class TwoFaTemplateResource(BaseModel):
    """
    TwoFaTemplateResource
    """ # noqa: E501
    template_id: Optional[StrictInt] = Field(default=None, description="Unique, automatically generated by a system identifier of the template within the TwoFA service.")
    name: Optional[StrictStr] = Field(default=None, description="Name of the template.  A string of 3 to 50 characters.")
    text: Optional[StrictStr] = Field(default=None, description="The text of the template message.")
    countries: Optional[List[StrictStr]] = Field(default=None, description="Two-letter country code(s) for which the template must apply. Sending messages with the OTP code will only be possible if the recipient’s number belongs to the country you specify for the template.")
    status: Optional[OtpTemplateStatus] = None
    updated_at: Optional[datetime] = Field(default=None, description="Date and time of the last change of the template in ISO 8601 format.")
    __properties: ClassVar[List[str]] = ["template_id", "name", "text", "countries", "status", "updated_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TwoFaTemplateResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TwoFaTemplateResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "template_id": obj.get("template_id"),
            "name": obj.get("name"),
            "text": obj.get("text"),
            "countries": obj.get("countries"),
            "status": obj.get("status"),
            "updated_at": obj.get("updated_at")
        })
        return _obj


