# coding: utf-8

# flake8: noqa
"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from bsg_api.models.account_balance200_response import AccountBalance200Response
from bsg_api.models.account_tariffs200_response import AccountTariffs200Response
from bsg_api.models.alternative_channel import AlternativeChannel
from bsg_api.models.balance_schema import BalanceSchema
from bsg_api.models.campaign import Campaign
from bsg_api.models.campaign_details200_response import CampaignDetails200Response
from bsg_api.models.campaign_price200_response import CampaignPrice200Response
from bsg_api.models.campaign_price422_response import CampaignPrice422Response
from bsg_api.models.campaign_price_request import CampaignPriceRequest
from bsg_api.models.campaign_price_request_messages_item import CampaignPriceRequestMessagesItem
from bsg_api.models.campaign_response import CampaignResponse
from bsg_api.models.campaign_schema import CampaignSchema
from bsg_api.models.campaign_status import CampaignStatus
from bsg_api.models.campaign_stop200_response import CampaignStop200Response
from bsg_api.models.campaign_stop422_response import CampaignStop422Response
from bsg_api.models.cancel_otp200_response import CancelOtp200Response
from bsg_api.models.cancel_otp404_response import CancelOtp404Response
from bsg_api.models.cancel_otp422_response import CancelOtp422Response
from bsg_api.models.card import Card
from bsg_api.models.cards import Cards
from bsg_api.models.click_resource import ClickResource
from bsg_api.models.components import Components
from bsg_api.models.contact200_response import Contact200Response
from bsg_api.models.contact422_response import Contact422Response
from bsg_api.models.contact_create201_response import ContactCreate201Response
from bsg_api.models.contact_create422_response import ContactCreate422Response
from bsg_api.models.contact_field_collection_schema import ContactFieldCollectionSchema
from bsg_api.models.contact_field_create201_response import ContactFieldCreate201Response
from bsg_api.models.contact_field_create_request import ContactFieldCreateRequest
from bsg_api.models.contact_field_schema import ContactFieldSchema
from bsg_api.models.contact_field_type import ContactFieldType
from bsg_api.models.contact_field_update200_response import ContactFieldUpdate200Response
from bsg_api.models.contact_field_update_request import ContactFieldUpdateRequest
from bsg_api.models.contact_field_update_request_option_description import ContactFieldUpdateRequestOptionDescription
from bsg_api.models.contact_field_update_request_option_is_visible import ContactFieldUpdateRequestOptionIsVisible
from bsg_api.models.contact_field_update_request_option_name import ContactFieldUpdateRequestOptionName
from bsg_api.models.contact_field_value_pair import ContactFieldValuePair
from bsg_api.models.contact_group_schema import ContactGroupSchema
from bsg_api.models.contact_group_search_field import ContactGroupSearchField
from bsg_api.models.contact_group_search_schema import ContactGroupSearchSchema
from bsg_api.models.contact_list200_response import ContactList200Response
from bsg_api.models.contact_list_attach_request import ContactListAttachRequest
from bsg_api.models.contact_list_create201_response import ContactListCreate201Response
from bsg_api.models.contact_list_create422_response import ContactListCreate422Response
from bsg_api.models.contact_list_create_request import ContactListCreateRequest
from bsg_api.models.contact_list_detach_request import ContactListDetachRequest
from bsg_api.models.contact_list_search200_response import ContactListSearch200Response
from bsg_api.models.contact_list_search_criteria import ContactListSearchCriteria
from bsg_api.models.contact_list_search_meta import ContactListSearchMeta
from bsg_api.models.contact_list_update200_response import ContactListUpdate200Response
from bsg_api.models.contact_list_update422_response import ContactListUpdate422Response
from bsg_api.models.contact_list_update_request import ContactListUpdateRequest
from bsg_api.models.contact_lists200_response import ContactLists200Response
from bsg_api.models.contact_schema import ContactSchema
from bsg_api.models.contact_update200_response import ContactUpdate200Response
from bsg_api.models.contact_update422_response import ContactUpdate422Response
from bsg_api.models.contact_update_request import ContactUpdateRequest
from bsg_api.models.contacts200_response import Contacts200Response
from bsg_api.models.contacts_search200_response import ContactsSearch200Response
from bsg_api.models.contacts_search_criteria import ContactsSearchCriteria
from bsg_api.models.contacts_search_meta import ContactsSearchMeta
from bsg_api.models.core_price_schema import CorePriceSchema
from bsg_api.models.country_item import CountryItem
from bsg_api.models.create_job_message import CreateJobMessage
from bsg_api.models.create_job_params import CreateJobParams
from bsg_api.models.currency_item import CurrencyItem
from bsg_api.models.detail_campaign_schema import DetailCampaignSchema
from bsg_api.models.detail_campaign_schema_alternative_channels import DetailCampaignSchemaAlternativeChannels
from bsg_api.models.detail_campaign_schema_alternative_channels_sms import DetailCampaignSchemaAlternativeChannelsSms
from bsg_api.models.detail_campaign_schema_alternative_channels_statistics import DetailCampaignSchemaAlternativeChannelsStatistics
from bsg_api.models.domain_store_request import DomainStoreRequest
from bsg_api.models.domain_update_request import DomainUpdateRequest
from bsg_api.models.email_response import EmailResponse
from bsg_api.models.get_internal2fa_authentications_full_price200_response import GetInternal2faAuthenticationsFullPrice200Response
from bsg_api.models.get_internal_core_prices200_response import GetInternalCorePrices200Response
from bsg_api.models.get_internal_core_prices_by_country_code200_response import GetInternalCorePricesByCountryCode200Response
from bsg_api.models.get_internal_countries200_response import GetInternalCountries200Response
from bsg_api.models.get_internal_currencies200_response import GetInternalCurrencies200Response
from bsg_api.models.get_internal_wst_prices200_response import GetInternalWstPrices200Response
from bsg_api.models.get_internal_wst_prices_by_country_code200_response import GetInternalWstPricesByCountryCode200Response
from bsg_api.models.get_messages200_response import GetMessages200Response
from bsg_api.models.groups_trait import GroupsTrait
from bsg_api.models.individual_message_data import IndividualMessageData
from bsg_api.models.inline import Inline
from bsg_api.models.language import Language
from bsg_api.models.link_store_request import LinkStoreRequest
from bsg_api.models.link_update_request import LinkUpdateRequest
from bsg_api.models.login_request import LoginRequest
from bsg_api.models.media import Media
from bsg_api.models.message_api_schema import MessageApiSchema
from bsg_api.models.message_api_schema_alternative_channels import MessageApiSchemaAlternativeChannels
from bsg_api.models.message_api_schema_alternative_channels_sms import MessageApiSchemaAlternativeChannelsSms
from bsg_api.models.message_api_schema_alternative_channels_sms_details import MessageApiSchemaAlternativeChannelsSmsDetails
from bsg_api.models.message_api_schema_alternative_channels_viber import MessageApiSchemaAlternativeChannelsViber
from bsg_api.models.message_api_schema_alternative_channels_viber_details import MessageApiSchemaAlternativeChannelsViberDetails
from bsg_api.models.message_info import MessageInfo
from bsg_api.models.message_price_object import MessagePriceObject
from bsg_api.models.message_response import MessageResponse
from bsg_api.models.message_source import MessageSource
from bsg_api.models.message_status import MessageStatus
from bsg_api.models.message_type import MessageType
from bsg_api.models.message_universal import MessageUniversal
from bsg_api.models.meta import Meta
from bsg_api.models.meta_page import MetaPage
from bsg_api.models.operator_schema import OperatorSchema
from bsg_api.models.options import Options
from bsg_api.models.otp_channel import OtpChannel
from bsg_api.models.otp_list200_response import OtpList200Response
from bsg_api.models.otp_list_response_data import OtpListResponseData
from bsg_api.models.otp_message_status import OtpMessageStatus
from bsg_api.models.otp_status import OtpStatus
from bsg_api.models.otp_template200_response import OtpTemplate200Response
from bsg_api.models.otp_template404_response import OtpTemplate404Response
from bsg_api.models.otp_template_create200_response import OtpTemplateCreate200Response
from bsg_api.models.otp_template_create422_response import OtpTemplateCreate422Response
from bsg_api.models.otp_template_create_request import OtpTemplateCreateRequest
from bsg_api.models.otp_template_delete200_response import OtpTemplateDelete200Response
from bsg_api.models.otp_template_delete404_response import OtpTemplateDelete404Response
from bsg_api.models.otp_template_delete422_response import OtpTemplateDelete422Response
from bsg_api.models.otp_template_delete_response_data import OtpTemplateDeleteResponseData
from bsg_api.models.otp_template_list200_response import OtpTemplateList200Response
from bsg_api.models.otp_template_list_response_data import OtpTemplateListResponseData
from bsg_api.models.otp_template_status import OtpTemplateStatus
from bsg_api.models.parameter import Parameter
from bsg_api.models.phone import Phone
from bsg_api.models.phones_trait import PhonesTrait
from bsg_api.models.post_contacts_fields_delete_request import PostContactsFieldsDeleteRequest
from bsg_api.models.rcs import Rcs
from bsg_api.models.rcs_click_callback import RcsClickCallback
from bsg_api.models.rcs_message import RcsMessage
from bsg_api.models.rcs_send200_response import RcsSend200Response
from bsg_api.models.rcs_send_groups200_response import RcsSendGroups200Response
from bsg_api.models.rcs_status_callback import RcsStatusCallback
from bsg_api.models.recipients import Recipients
from bsg_api.models.resend_otp200_response import ResendOtp200Response
from bsg_api.models.resend_otp404_response import ResendOtp404Response
from bsg_api.models.resend_otp422_response import ResendOtp422Response
from bsg_api.models.search_campaign_resource import SearchCampaignResource
from bsg_api.models.search_operator import SearchOperator
from bsg_api.models.send_email import SendEmail
from bsg_api.models.send_otp201_response import SendOtp201Response
from bsg_api.models.send_otp422_response import SendOtp422Response
from bsg_api.models.send_otp_request import SendOtpRequest
from bsg_api.models.send_rcs_campaign import SendRcsCampaign
from bsg_api.models.send_rcs_campaign_groups import SendRcsCampaignGroups
from bsg_api.models.send_rcs_campaign_groups_alternative_channel import SendRcsCampaignGroupsAlternativeChannel
from bsg_api.models.send_template_email import SendTemplateEmail
from bsg_api.models.send_viber_campaign import SendViberCampaign
from bsg_api.models.send_whats_app_campaign import SendWhatsAppCampaign
from bsg_api.models.send_whats_app_campaign_alternative_channel import SendWhatsAppCampaignAlternativeChannel
from bsg_api.models.sender_request_legal201_response import SenderRequestLegal201Response
from bsg_api.models.sender_request_legal_request import SenderRequestLegalRequest
from bsg_api.models.sender_request_legal_schema import SenderRequestLegalSchema
from bsg_api.models.sender_request_natural201_response import SenderRequestNatural201Response
from bsg_api.models.sender_request_natural_request import SenderRequestNaturalRequest
from bsg_api.models.sender_request_natural_schema import SenderRequestNaturalSchema
from bsg_api.models.sender_request_schema import SenderRequestSchema
from bsg_api.models.sender_request_status import SenderRequestStatus
from bsg_api.models.sender_request_type import SenderRequestType
from bsg_api.models.sender_requests200_response import SenderRequests200Response
from bsg_api.models.sender_schema import SenderSchema
from bsg_api.models.senders200_response import Senders200Response
from bsg_api.models.short_domain_not_found import ShortDomainNotFound
from bsg_api.models.short_domain_slug_type import ShortDomainSlugType
from bsg_api.models.short_link import ShortLink
from bsg_api.models.short_link_status import ShortLinkStatus
from bsg_api.models.short_url_domain_list_schema import ShortUrlDomainListSchema
from bsg_api.models.short_url_domain_schema import ShortUrlDomainSchema
from bsg_api.models.short_url_link_schema import ShortUrlLinkSchema
from bsg_api.models.short_urls_clicks200_response import ShortUrlsClicks200Response
from bsg_api.models.short_urls_domain200_response import ShortUrlsDomain200Response
from bsg_api.models.short_urls_domain_create201_response import ShortUrlsDomainCreate201Response
from bsg_api.models.short_urls_domain_create422_response import ShortUrlsDomainCreate422Response
from bsg_api.models.short_urls_domain_update200_response import ShortUrlsDomainUpdate200Response
from bsg_api.models.short_urls_domains200_response import ShortUrlsDomains200Response
from bsg_api.models.short_urls_link200_response import ShortUrlsLink200Response
from bsg_api.models.short_urls_link404_response import ShortUrlsLink404Response
from bsg_api.models.short_urls_link_create201_response import ShortUrlsLinkCreate201Response
from bsg_api.models.short_urls_link_delete422_response import ShortUrlsLinkDelete422Response
from bsg_api.models.short_urls_link_statistic_data import ShortUrlsLinkStatisticData
from bsg_api.models.short_urls_link_update200_response import ShortUrlsLinkUpdate200Response
from bsg_api.models.short_urls_link_update422_response import ShortUrlsLinkUpdate422Response
from bsg_api.models.short_urls_links200_response import ShortUrlsLinks200Response
from bsg_api.models.sms import Sms
from bsg_api.models.sms_alt_channel import SmsAltChannel
from bsg_api.models.sms_campaign_response import SmsCampaignResponse
from bsg_api.models.sms_send_groups_request import SmsSendGroupsRequest
from bsg_api.models.sms_send_individual_request import SmsSendIndividualRequest
from bsg_api.models.sms_send_request import SmsSendRequest
from bsg_api.models.sms_send_request_phones_item import SmsSendRequestPhonesItem
from bsg_api.models.sort_way import SortWay
from bsg_api.models.stat_jobs_create200_response import StatJobsCreate200Response
from bsg_api.models.stat_jobs_create_request import StatJobsCreateRequest
from bsg_api.models.stat_jobs_delete200_response import StatJobsDelete200Response
from bsg_api.models.statistics_data import StatisticsData
from bsg_api.models.statistics_short import StatisticsShort
from bsg_api.models.status_otp200_response import StatusOtp200Response
from bsg_api.models.status_otp404_response import StatusOtp404Response
from bsg_api.models.stop_list_collection import StopListCollection
from bsg_api.models.stop_list_paginate_schema import StopListPaginateSchema
from bsg_api.models.stoplist_add200_response import StoplistAdd200Response
from bsg_api.models.stoplist_add_request import StoplistAddRequest
from bsg_api.models.stoplist_items200_response import StoplistItems200Response
from bsg_api.models.stoplist_remove_request import StoplistRemoveRequest
from bsg_api.models.stoplist_search200_response import StoplistSearch200Response
from bsg_api.models.stoplist_search_criteria import StoplistSearchCriteria
from bsg_api.models.stoplist_search_field import StoplistSearchField
from bsg_api.models.stoplist_search_meta import StoplistSearchMeta
from bsg_api.models.store_contact import StoreContact
from bsg_api.models.suggestion import Suggestion
from bsg_api.models.suggestion_call import SuggestionCall
from bsg_api.models.suggestion_link import SuggestionLink
from bsg_api.models.tariff_schema import TariffSchema
from bsg_api.models.telegram import Telegram
from bsg_api.models.template import Template
from bsg_api.models.text import Text
from bsg_api.models.token_schema import TokenSchema
from bsg_api.models.too_many_requests_response import TooManyRequestsResponse
from bsg_api.models.two_fa_template_resource import TwoFaTemplateResource
from bsg_api.models.two_factor_authentication_messages_resource import TwoFactorAuthenticationMessagesResource
from bsg_api.models.two_factor_authentication_schema import TwoFactorAuthenticationSchema
from bsg_api.models.two_factor_message_resource import TwoFactorMessageResource
from bsg_api.models.verify_otp200_response import VerifyOtp200Response
from bsg_api.models.verify_otp404_response import VerifyOtp404Response
from bsg_api.models.verify_otp422_response import VerifyOtp422Response
from bsg_api.models.verify_otp_request import VerifyOtpRequest
from bsg_api.models.viber import Viber
from bsg_api.models.viber_campaign_response import ViberCampaignResponse
from bsg_api.models.voice import Voice
from bsg_api.models.whats_app_message import WhatsAppMessage
from bsg_api.models.whats_app_message_alternative_channel import WhatsAppMessageAlternativeChannel
from bsg_api.models.whats_app_message_template import WhatsAppMessageTemplate
from bsg_api.models.wst_price_schema import WstPriceSchema
