# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from bsg_api.models.short_link import ShortLink
from typing import Optional, Set
from typing_extensions import Self

class SmsSendGroupsRequest(BaseModel):
    """
    SmsSendGroupsRequest
    """ # noqa: E501
    groups: Optional[Annotated[List[StrictInt], Field(min_length=1)]] = Field(default=None, description="one or several contact list id to send messages. id of the lists can be obtained: using the Get [lists API](#tag/Contact-List) in your account [Contact Book → Lists](https://app.bsg.world/addressbook/lists)")
    sender: StrictStr = Field(description="Sender’s name: from 3 to 11 characters for the sender’s alphanumeric name (Latin letters, symbols, numbers, spaces); 3 to 15 characters for the sender’s numeric name. To setup senders visit the [account](https://app.bsg.world/sms/senders)")
    text: Annotated[str, Field(strict=True, max_length=765)] = Field(description="SMS text, max length is 765 chars for GSM 7-bit encoding (Latin), and 355 for UCS-2")
    tariff_code: Optional[StrictInt] = Field(default=None, description="Tariff code null by default. Your can pass specified one if you have several. For more information please visit the [account prices](https://app.bsg.world/prices/sms)")
    validity: Optional[Annotated[int, Field(le=72, strict=True, ge=1)]] = Field(default=72, description="validity time in hours. The default is 72 hours. Integer from 1 to 72")
    start_at: Optional[datetime] = Field(default=None, description="Start sending the messages at")
    short_links: Optional[List[ShortLink]] = None
    transliterate: Optional[StrictBool] = Field(default=False, description="apply transliteration to sms text if it necessary")
    callback_url: Optional[Any] = Field(default=None, description="Link to get the delivery status of messages. If this parameter is specified in the method, it will take precedence over the value specified in the “Callback URL” field in the Personal Area.")
    __properties: ClassVar[List[str]] = ["groups", "sender", "text", "tariff_code", "validity", "start_at", "short_links", "transliterate", "callback_url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SmsSendGroupsRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in short_links (list)
        _items = []
        if self.short_links:
            for _item_short_links in self.short_links:
                if _item_short_links:
                    _items.append(_item_short_links.to_dict())
            _dict['short_links'] = _items
        # set to None if callback_url (nullable) is None
        # and model_fields_set contains the field
        if self.callback_url is None and "callback_url" in self.model_fields_set:
            _dict['callback_url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SmsSendGroupsRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "groups": obj.get("groups"),
            "sender": obj.get("sender"),
            "text": obj.get("text"),
            "tariff_code": obj.get("tariff_code"),
            "validity": obj.get("validity") if obj.get("validity") is not None else 72,
            "start_at": obj.get("start_at"),
            "short_links": [ShortLink.from_dict(_item) for _item in obj["short_links"]] if obj.get("short_links") is not None else None,
            "transliterate": obj.get("transliterate") if obj.get("transliterate") is not None else False,
            "callback_url": obj.get("callback_url")
        })
        return _obj


