# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class MessageSource(str, Enum):
    """
    The source how message was sent by  - rest - by this api - web - by web interface of [personal account](https://app.bsg.world) - smpp - by smpp connection - 2fa - sent by 2fa - voicebot - sent by voicebot - twoway - two way sms by interface - twoway_api - two way sms by api - xml - service messages     
    """

    """
    allowed enum values
    """
    WEB = 'web'
    REST = 'rest'
    SMPP = 'smpp'
    XML = 'xml'
    TWOWAY = 'twoway'
    TWOWAY_API = 'twoway_api'
    ENUM_2FA = '2fa'
    VOICEBOT = 'voicebot'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MessageSource from a JSON string"""
        return cls(json.loads(json_str))


