# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from bsg_api.models.otp_channel import OtpChannel
from bsg_api.models.otp_message_status import OtpMessageStatus
from typing import Optional, Set
from typing_extensions import Self

class TwoFactorMessageResource(BaseModel):
    """
    TwoFactorMessageResource
    """ # noqa: E501
    id: Optional[StrictInt] = Field(default=None, description="The unique ID of the message")
    recipient: Optional[StrictStr] = Field(default=None, description="Number of the recipient of the message with a one-time code")
    status: Optional[OtpMessageStatus] = None
    channel: Optional[OtpChannel] = None
    sender: Optional[StrictStr] = Field(default=None, description="Sender name")
    price: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Message cost")
    currency: Optional[StrictStr] = Field(default=None, description="The three-letter code of the currency in which the value is indicated. Corresponds to the user’s account currency")
    sent_at: Optional[StrictStr] = Field(default=None, description="The date and time of the message were sent in ISO 8601 format")
    created_at: Optional[StrictStr] = Field(default=None, description="The date and time the message was created in ISO 8601 format")
    __properties: ClassVar[List[str]] = ["id", "recipient", "status", "channel", "sender", "price", "currency", "sent_at", "created_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TwoFactorMessageResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if sent_at (nullable) is None
        # and model_fields_set contains the field
        if self.sent_at is None and "sent_at" in self.model_fields_set:
            _dict['sent_at'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TwoFactorMessageResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "recipient": obj.get("recipient"),
            "status": obj.get("status"),
            "channel": obj.get("channel"),
            "sender": obj.get("sender"),
            "price": obj.get("price"),
            "currency": obj.get("currency"),
            "sent_at": obj.get("sent_at"),
            "created_at": obj.get("created_at")
        })
        return _obj


