# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class MessageType(str, Enum):
    """
    message type for example: sms
    """

    """
    allowed enum values
    """
    SMS = 'sms'
    VIBER = 'viber'
    HLR = 'hlr'
    RCS = 'rcs'
    WHATSAPP = 'whatsapp'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MessageType from a JSON string"""
        return cls(json.loads(json_str))


