# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class MessageStatus(str, Enum):
    """
    Message status
    """

    """
    allowed enum values
    """
    SCHEDULED = 'scheduled'
    MODERATION = 'moderation'
    ACCEPTED = 'accepted'
    SENDING = 'sending'
    SENT = 'sent'
    DELIVERED = 'delivered'
    EXPIRED = 'expired'
    FAILED = 'failed'
    UNDELIVERED = 'undelivered'
    UNKNOWN = 'unknown'
    READ = 'read'
    NOT_VIBER_USER = 'not_viber_user'
    NOT_SERVICE_USER = 'not_service_user'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MessageStatus from a JSON string"""
        return cls(json.loads(json_str))


